@@ -2,6 +2,7 @@
 
 #![deny(
     clippy::all,
+    clippy::cargo,
     missing_docs,
     missing_copy_implementations,
     missing_debug_implementations
@@ -9,7 +10,7 @@
 #![warn(clippy::pedantic)]
 
 use bytes::Buf;
-pub use bytes::BufMut;
+pub use bytes::{BufMut, Bytes, BytesMut};
 
 pub mod error;
 mod safe_buf;
